@@ -51,9 +51,7 @@ def read_tabular(filename, dtype_conversion=None):
     if "csv" in ext:
         df = pd.read_csv(filename, dtype=dtype_conversion, encoding="utf-8")
     elif "tsv" in ext:
-        df = pd.read_csv(
-            filename, sep="\t", dtype=dtype_conversion, encoding="utf-8"
-        )
+        df = pd.read_csv(filename, sep="\t", dtype=dtype_conversion, encoding="utf-8")
     elif "xls" in ext or "xlsx" in ext:
         df = pd.read_excel(filename, dtype=dtype_conversion)
     # TODO: Add a function to parse ODS data into a pandas data frame.
